@@ -2,11 +2,11 @@
 psycopg server-side cursor objects.
 """
 
-# Copyright (C) 2020-2021 The Psycopg Team
+# Copyright (C) 2020 The Psycopg Team
 
-import warnings
 from typing import Any, AsyncIterator, Generic, List, Iterable, Iterator
 from typing import Optional, TypeVar, TYPE_CHECKING
+from warnings import warn
 
 from . import pq
 from . import sql
@@ -70,7 +70,7 @@ class ServerCursorHelper(Generic[ConnectionType, Row]):
         cur._execute_send(pgq, no_pqexec=True)
         results = yield from execute(cur._conn.pgconn)
         if results[-1].status != pq.ExecStatus.COMMAND_OK:
-            cur._raise_from_results(results)
+            cur._raise_for_result(results[-1])
 
         # Set the format, which will be used by describe and fetch operations
         if binary is None:
@@ -81,14 +81,13 @@ class ServerCursorHelper(Generic[ConnectionType, Row]):
         # The above result only returned COMMAND_OK. Get the cursor shape
         yield from self._describe_gen(cur)
 
-    def _describe_gen(
-        self, cur: BaseCursor[ConnectionType, Row]
-    ) -> PQGen[None]:
+    def _describe_gen(self, cur: BaseCursor[ConnectionType, Row]) -> PQGen[None]:
         conn = cur._conn
         conn.pgconn.send_describe_portal(self.name.encode(cur._encoding))
         results = yield from execute(conn.pgconn)
-        cur._set_results(results)
-        cur._set_result(0, format=self._format)
+        cur._check_results(results)
+        cur._results = results
+        cur._set_current_result(0, format=self._format)
         self.described = True
 
     def _close_gen(self, cur: BaseCursor[ConnectionType, Row]) -> PQGen[None]:
@@ -129,9 +128,7 @@ class ServerCursorHelper(Generic[ConnectionType, Row]):
             sql.SQL("ALL") if num is None else sql.Literal(num),
             sql.Identifier(self.name),
         )
-        res = yield from cur._conn._exec_command(
-            query, result_format=self._format
-        )
+        res = yield from cur._conn._exec_command(query, result_format=self._format)
 
         cur.pgresult = res
         cur._tx.set_pgresult(res, set_loaders=False)
@@ -141,9 +138,7 @@ class ServerCursorHelper(Generic[ConnectionType, Row]):
         self, cur: BaseCursor[ConnectionType, Row], value: int, mode: str
     ) -> PQGen[None]:
         if mode not in ("relative", "absolute"):
-            raise ValueError(
-                f"bad mode: {mode}. It should be 'relative' or 'absolute'"
-            )
+            raise ValueError(f"bad mode: {mode}. It should be 'relative' or 'absolute'")
         query = sql.SQL("MOVE{} {} FROM {}").format(
             sql.SQL(" ABSOLUTE" if mode == "absolute" else ""),
             sql.Literal(value),
@@ -199,9 +194,9 @@ class ServerCursor(Cursor[Row]):
 
     def __del__(self) -> None:
         if not self.closed:
-            warnings.warn(
+            warn(
                 f"the server-side cursor {self} was deleted while still open."
-                f" Please use 'with' or '.close()' to close the cursor properly",
+                " Please use 'with' or '.close()' to close the cursor properly",
                 ResourceWarning,
             )
 
@@ -257,9 +252,7 @@ class ServerCursor(Cursor[Row]):
 
         try:
             with self._conn.lock:
-                self._conn.wait(
-                    self._helper._declare_gen(self, query, params, binary)
-                )
+                self._conn.wait(self._helper._declare_gen(self, query, params, binary))
         except e.Error as ex:
             raise ex.with_traceback(None)
 
@@ -267,9 +260,7 @@ class ServerCursor(Cursor[Row]):
 
     def executemany(self, query: Query, params_seq: Iterable[Params]) -> None:
         """Method not implemented for server-side cursors."""
-        raise e.NotSupportedError(
-            "executemany not supported on server-side cursors"
-        )
+        raise e.NotSupportedError("executemany not supported on server-side cursors")
 
     def fetchone(self) -> Optional[Row]:
         with self._conn.lock:
@@ -297,9 +288,7 @@ class ServerCursor(Cursor[Row]):
     def __iter__(self) -> Iterator[Row]:
         while True:
             with self._conn.lock:
-                recs = self._conn.wait(
-                    self._helper._fetch_gen(self, self.itersize)
-                )
+                recs = self._conn.wait(self._helper._fetch_gen(self, self.itersize))
             for rec in recs:
                 self._pos += 1
                 yield rec
@@ -336,9 +325,9 @@ class AsyncServerCursor(AsyncCursor[Row]):
 
     def __del__(self) -> None:
         if not self.closed:
-            warnings.warn(
+            warn(
                 f"the server-side cursor {self} was deleted while still open."
-                f" Please use 'with' or '.close()' to close the cursor properly",
+                " Please use 'with' or '.close()' to close the cursor properly",
                 ResourceWarning,
             )
 
@@ -385,12 +374,8 @@ class AsyncServerCursor(AsyncCursor[Row]):
 
         return self
 
-    async def executemany(
-        self, query: Query, params_seq: Iterable[Params]
-    ) -> None:
-        raise e.NotSupportedError(
-            "executemany not supported on server-side cursors"
-        )
+    async def executemany(self, query: Query, params_seq: Iterable[Params]) -> None:
+        raise e.NotSupportedError("executemany not supported on server-side cursors")
 
     async def fetchone(self) -> Optional[Row]:
         async with self._conn.lock:
